<?php 

namespace Drupal\hubspot_integration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\PluginFormInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configures Hubspot settings for this site.
 *
 */
class HubspotAdminForm extends ConfigFormBase {
  
  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }
  
  /**
   * Constructs a \Drupal\HubspotIntegration\Form\HubspotAdminForm object.
   *
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);
  }
  
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'hubspot_integration_admin_form';
  }
  
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['hubspot_integration.settings'];
  }
  
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('hubspot_integration.settings');
    
    $form['client_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client ID'),
      '#default_value' => $config->get('client_id'),
    ];
    
    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $config->get('api_key'),
    ];
    
    $form['demo_mode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Demo mode (disable all cached and session limitation, usefull for a demo and see changes immediatly)'),
      '#default_value' => $config->get('demo_mode'),
    ];
    
    $form['anonymous_contact'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Automatically create new contacts for anonymous visitors'),
      '#default_value' => $config->get('anonymous_contact'),
    ];
    
    return parent::buildForm($form, $form_state);
  }
  
  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }
  
  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->config('hubspot_integration.settings');
    
    $config->set('client_id', $form_state->getValue('client_id'));
    $config->set('api_key', $form_state->getValue('api_key'));
    $config->set('demo_mode', $form_state->getValue('demo_mode'));
    $config->set('anonymous_contact', $form_state->getValue('anonymous_contact'));
    
    $config->save();
  }
}